..  SOMA documentation master file, created by
    sphinx-quickstart on Wed Sep  4 12:18:01 2013.
    You can adapt this file completely to your liking, but it should at least
    contain the root `toctree` directive.


SOMA
====

Bla

Contents
========
.. toctree::
    :maxdepth: 1

    installation
    documentation


Search
=======

:ref:`search`





